﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Runtime.InteropServices;
using System.ComponentModel;

namespace ActiveXLibrary
{
    /// <summary>
    /// 录音核心类
    /// </summary>
    [Description("录音核心类")]
    public class RecordCore
    {
        #region

        [DllImport("winmm.dll", EntryPoint = "mciSendString", CharSet = CharSet.Auto)]
        public static extern int mciSendString(string lpstrCommand, string lpstrReturnString, int uReturnLength, int hwndCallback);

        /// <summary>
        /// 录音状态
        /// </summary>
        public RecordStatus RecordStatus = RecordStatus.Close;

        #endregion

        /// <summary>
        /// 开始录音
        /// </summary>
        /// <returns></returns>
        public void StartRecord()
        {
            mciSendString("close myrecord", "", 0, 0);

            int result = mciSendString("open new type WAVEAudio alias myrecord", "", 0, 0);
            if (result != 0)
            {
                throw new Exception(result.ToString());
            }

            result = mciSendString("record myrecord", "", 0, 0);
            if (result != 0)
            {
                throw new Exception(result.ToString());
            }

            this.RecordStatus = ActiveXLibrary.RecordStatus.Record;

            //result = mciSendString("set wave  bitpersample 8", "", 0, 0);
            //result = mciSendString("set wave  samplespersec 11025", "", 0, 0);
            // result = mciSendString("set wave  channels 2", "", 0, 0);
            //result = mciSendString("set wave  format tag pcm", "", 0, 0);
        }

        /// <summary>
        /// 暂停录音
        /// </summary>
        public void PauseRecord()
        {
            int result = mciSendString("pause myrecord", "", 0, 0);
            if (result != 0)
            {
                throw new Exception(result.ToString());
            }

            this.RecordStatus = ActiveXLibrary.RecordStatus.Pause;
        }

        /// <summary>
        /// 继续录音
        /// </summary>
        public void ResumeRecord()
        {
            int result = mciSendString("resume  myrecord", "", 0, 0);
            if (result != 0)
            {
                throw new Exception(result.ToString());
            }

            this.RecordStatus = ActiveXLibrary.RecordStatus.Record;
        }

        /// <summary>
        /// 保存录音
        /// </summary>
        /// <param name="pathFile">保存路径(不能有数字)</param>
        public void SaveRecord(string pathFile)
        {
            this.PauseRecord();

            int result = mciSendString(String.Format("save myrecord {0} ", pathFile), "", 0, 0);
            if (result != 0)
            {
                throw new Exception(result.ToString());
            }

            this.CloseRecord();
        }

        /// <summary>
        /// .关闭录音
        /// </summary>
        public void CloseRecord()
        {
            int result = mciSendString("close myrecord", "", 0, 0);
            if (result != 0)
            {
                throw new Exception(result.ToString());
            }

            this.RecordStatus = ActiveXLibrary.RecordStatus.Close;
        }

    }

    /// <summary>
    /// 录音状态
    /// </summary>
    [Description("录音状态")]
    public enum RecordStatus
    {
        /// <summary>
        /// 录音
        /// </summary>
        Record,
        /// <summary>
        /// 暂停
        /// </summary>
        Pause,
        /// <summary>
        /// 关闭
        /// </summary>
        Close

    }
}
